import { r as registerInstance, h, H as Host } from './core-8406794d.js';

var ButtonVariants;
(function (ButtonVariants) {
    ButtonVariants["default"] = "default";
    ButtonVariants["secondary"] = "secondary";
    ButtonVariants["outline"] = "outline";
})(ButtonVariants || (ButtonVariants = {}));

const colors = {
    brandMain: "#0E688B",
    brandActive: "#005379",
    brandMainLight: "#107EAB",
    brandMainDark: "#005379",
    grayscaleWhite: "#FFF",
    grayscaleLight: "#F8F8F8",
    grayscaleMedium: "#D2D2D2",
    grayscaleMediumDark: "#979797",
    grayscaleDark: "#424242",
    grayscaleBlack: "#222"
};

const fillcolors = {
    default: "white",
    secondary: colors.brandMain,
    outline: colors.brandMain
};
const Button = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.variant = ButtonVariants.default;
    }
    render() {
        const iconFillColor = fillcolors[this.variant];
        const classAttributes = ["hy-button", this.variant];
        return (h(Host, null, h("button", { class: classAttributes.join(" ") }, !!this.icon && (h("span", { class: "button-icon button-icon-left" }, h("hy-icon", { icon: this.icon, fill: iconFillColor, size: 13 }))), h("span", { class: "button-text" }, h("slot", null)), !!this.iconRight && (h("span", { class: "button-icon button-icon-right" }, h("hy-icon", { icon: this.iconRight, fill: iconFillColor, size: 13 }))))));
    }
    static get style() { return ":host{display:block}button{display:block;font-family:Open Sans,Helvetica,Arial,sans-serif;font-size:.9375rem;line-height:.9375rem;background-color:var(--brand-main);border:none;color:var(--grayscale-white);cursor:pointer;padding:0 1rem;margin:0;height:2.75rem;-webkit-transition-duration:.1s;transition-duration:.1s;-webkit-transition-property:all;transition-property:all;display:-ms-flexbox;display:flex;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;align-items:center;border-width:2px;border-style:solid;border-color:var(--brand-main)}button.secondary{background-color:#fff}button.outline,button.secondary{color:var(--brand-main);border-color:var(--brand-main)}button.outline{background-color:transparent}button.default:hover{background-color:var(--brand-main-active)}button.default:active{position:relative;top:1px;background-color:var(--brand-main-dark)}button:focus{outline-width:1;outline-color:orange}button.default svg{fill:#fff}.button-text{margin:0 .75rem}.button-icon{margin:0;display:-ms-flexbox;display:flex;-ms-flex-align:center;align-items:center;-ms-flex-line-pack:center;align-content:center}"; }
};

const DocsContainer = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return (h("div", { class: "hy-docs-container" }, h("slot", null)));
    }
    static get style() { return "div.hy-docs-container{display:block;margin:2rem 0}"; }
};

function SvgCamera(props) {
    return (h("svg", Object.assign({ viewBox: "0 0 1000 1000" }, props),
        h("path", { d: "M32 161v678h936V161H32zm452 549q-57 0-105-29t-77-76-28-105 28-105 77-77 105-28 105 28 77 77 28 105-28 105-77 76-105 29zm290-339q-26 0-45-19t-19-46 19-45 46-19 45 19 19 45-19 46-46 19z" })));
}

function SvgHyLogo(props) {
    return (h("svg", Object.assign({ viewBox: "0 0 1000 1000" }, props),
        h("path", { d: "M452 0h96v97h-96V0zm0 903h96v97h-96v-97zm380-358q-32-20-38-74-25 3-44-3-28-10-40-42-6-13-12-47t-13-52q-12-32-33-56-33-35-74-50-37-14-78-11 30 19 37 46 6 23-7 41t-36 19-42-12q-8-5-35-27-22-18-40-26-26-12-58-12-25 0-51 13 24 3 40 16 13 12 24 32 3 7 16 39 10 23 27 36t44 22q-13 6-38 6-29 0-55-15-20-11-45-36t-43-36q-28-16-61-16-16 0-29 4t-19 9q23 3 42 14 23 15 23 34 0 11-7 17t-19 5-23-12q-18-20-43-33t-54-12q-13 0-26 3T0 339q34 5 58 28t45 72q15 35 33 51 24 23 64 23 5 0 29-3 20-2 31 0 17 2 27 13 9 8 12 21 2 6 5 23 2 15 6 23 10 21 28 31 21 11 56 11-19 19-54 21-32 2-65-9t-49-28q2 46 25 80 25 37 68 50 49 14 113-4 18-5 30-1t19 24q16 41 71 35 48-5 79 6t59 42q8-81-77-135-15-9-23-19-6-8-9-19l-4-17q16 18 38 28 17 8 43 14 82 10 110 52 2-23-6-42-6-15-19-29-10-10-26-22-19-15-23-18-11-10-13-18 19 12 36 17t38 5q7-1 27-6t31-4q16 0 28 7 15 9 27 29 29-18 68-15 35 3 64 21-12-30-34-52-17-18-44-33-12-7-47-23-28-14-43-24zm-284 36h-96v-97h96v97z" })));
}

function SvgImageGallery(props) {
    return (h("svg", Object.assign({ viewBox: "0 0 1000 1000" }, props),
        h("path", { d: "M728 732q30 0 51-21t21-51V205q0-30-21-51t-51-21H72q-30 0-51 21T0 205v455q0 30 21 51t51 21h656zM72 694q-14 0-24-10t-10-24V205q0-14 10-25t24-10h656q15 0 25 10t10 25v455q0 14-10 24t-25 10H72zm440-224l-112-38-97 87-154 115h570V500l-12-9q-14-14-29-33-20-26-38-60-22-41-38-92-10-31-34 12-16 30-38 94zM278 306q0 35-24 59t-59 25-59-25-24-59 24-59 59-24 59 24 24 59zm517-81q14 0 24 10t10 25v455q0 14-10 24t-24 10H138q-14 0-24-10t-10-24H67q0 30 21 51t50 21h657q30 0 51-21t21-51V260q0-30-21-51t-51-21v37zm133 113q14 0 25 10t10 25v455q0 14-10 24t-25 10H272q-15 0-25-10t-10-24h-37q0 30 21 51t51 21h656q30 0 51-21t21-51V373q0-30-21-51t-51-21v37zm-66-58q14 0 24 10t10 25v455q0 14-10 24t-24 10H205q-14 0-24-10t-10-24h-38q0 30 21 51t51 21h657q29 0 50-21t21-51V315q0-30-21-51t-50-21v37z" })));
}

const IconArrowLeft = (props) => {
    return (h("svg", { xmlns: "http://www.w3.org/2000/svg", width: props.width || 30, height: props.height || 29, viewBox: "0 0 30 29", fill: props.fill || "black" },
        h("polygon", { points: "29.207 13.783 14.756 .717 14.055 0 11.402 3.118 10.732 3.835 19.665 11.974 0 11.974 0 17.026 19.756 17.026 11.494 24.447 10.823 25.071 11.402 25.882 13.476 28.189 14.055 29 30 14.594", transform: "rotate(-180 15 14.5)" })));
};
const IconArrowRight = (props) => {
    return (h("svg", { xmlns: "http://www.w3.org/2000/svg", width: props.width || 30, height: props.height || 29, viewBox: "0 0 30 29", fill: props.fill || "black" },
        h("polygon", { points: "29.207 13.783 14.756 .717 14.055 0 11.402 3.118 10.732 3.835 19.665 11.974 0 11.974 0 17.026 19.756 17.026 11.494 24.447 10.823 25.071 11.402 25.882 13.476 28.189 14.055 29 30 14.594" })));
};

// TODO: add all icons
const iconNames = {
    "hy-icon-arrow-left": p => h(IconArrowLeft, Object.assign({}, p)),
    "hy-icon-arrow-right": p => h(IconArrowRight, Object.assign({}, p)),
    "hy-icon-hy-logo": p => h(SvgHyLogo, Object.assign({}, p)),
    "hy-icon-camera": p => h(SvgCamera, Object.assign({}, p)),
    "hy-icon-image-gallery": p => h(SvgImageGallery, Object.assign({}, p))
};
const Icon = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.fill = "black";
        this.size = 20;
    }
    render() {
        return (h(Host, { "aria-hidden": "true", style: { display: "flex" } }, iconNames[this.icon]({
            height: this.size,
            width: this.size,
            fill: this.fill
        })));
    }
    static get style() { return ":host{display:block}"; }
};

const Row = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.justify = "flex-start";
        this.align = "center";
    }
    render() {
        return (h("div", { class: "hy-row", style: {
                justifyContent: this.justify,
                alignContent: this.align
            } }, h("slot", null)));
    }
    static get style() { return "div.hy-row{display:-ms-flexbox;display:flex;-ms-flex-direction:row;flex-direction:row}div.hy-row>*+*{margin-left:1rem}"; }
};

export { Button as hy_button, DocsContainer as hy_docs_container, Icon as hy_icon, Row as hy_row };
